@@ -1,5 +1,5 @@
 package App::bmkpasswd;
-$App::bmkpasswd::VERSION = '2.006001';
+$App::bmkpasswd::VERSION = '2.007001';
 use strictures 2;
 use Carp;
 use Try::Tiny;
@@ -10,10 +10,11 @@ use Crypt::Eksblowfish::Bcrypt qw/
 /;
 
 use parent 'Exporter::Tiny';
-our @EXPORT_OK = qw/
+our @EXPORT = qw/
   mkpasswd
-  passwdcmp
-
+  passwdcmp 
+/;
+our @EXPORT_OK = qw/
   mkpasswd_available
   mkpasswd_forked
 /;
@@ -133,16 +134,12 @@ sub mkpasswd {
   croak "mkpasswd passed an undef password"
     unless defined $pwd;
 
-  my %opts;
-  if (ref $_[0] eq 'HASH') {
-    %opts = %{ $_[0] };
-  } elsif (@_) {
-    @opts{qw/type cost strong/} = @_;
-  }
-
+  my %opts =
+    ref $_[0] eq 'HASH' ? %{ $_[0] }
+    : map {; $_ => shift } qw/type cost strong/;
   my $type = defined $opts{type} ? $opts{type} : 'bcrypt';
-
   my $saltgen = $opts{saltgen} || $_saltgen;
+
   my $salt;
 
   TYPE: {
@@ -210,7 +207,7 @@ sub passwdcmp {
     }
   }
 
-  ()
+  undef
 }
 
 1;
@@ -226,7 +223,7 @@ App::bmkpasswd - bcrypt-capable mkpasswd(1) and exported helpers
 
   ## From Perl:
 
-  use App::bmkpasswd 'mkpasswd', 'passwdcmp';
+  use App::bmkpasswd -all;
   my $bcrypted = mkpasswd($passwd);
   say 'matched' if passwdcmp($passwd, $bcrypted);
 
@@ -300,8 +297,9 @@ Compare a password against a hash.
     ## Failed match
   }
 
-B<passwdcmp> will return the hash if it is a match; otherwise, an empty list
-is returned.
+B<passwdcmp> will return the hash if it is a match; otherwise, C<undef>
+is returned. (This is an API change in C<v2.7.1>; prior versions return
+an empty list on failure.)
 
 =head2 mkpasswd
 
@@ -392,6 +390,8 @@ it's advisable to either only load this module after creating the new process
 or call B<mkpasswd_forked> in the new process to reset the random seeds used
 by salt generators.
 
+Added in C<v2.6.1>.
+
 =head1 AUTHOR
 
 Jon Portnoy <avenj@cobaltirc.org>
