@@ -1,8 +1,8 @@
 package Crypt::Bcrypt::Easy;
-$Crypt::Bcrypt::Easy::VERSION = '2.006001';
+$Crypt::Bcrypt::Easy::VERSION = '2.007001';
 use Carp;
 use strictures 2;
-use App::bmkpasswd 'mkpasswd', 'passwdcmp';
+use App::bmkpasswd 'mkpasswd', 'passwdcmp', 'mkpasswd_forked';
 
 use Scalar::Util 'blessed';
 
@@ -19,6 +19,7 @@ sub bcrypt {  Crypt::Bcrypt::Easy->new(@_)  }
 sub new {
   my ($cls, %params) = @_;
   my $cost = $params{cost} || '08';
+  mkpasswd_forked if $params{reset_seed};
   bless \$cost, blessed($cls) || $cls
 }
 
@@ -100,16 +101,25 @@ as-needed:
 
 =head2 bcrypt
 
-  my $bcrypt = bcrypt( cost => '10' );
+  my $bcrypt = bcrypt( cost => 10 );
 
 Creates and returns a new Crypt::Bcrypt::Easy object.
 
-The default workcost is '08'. This can be also be tuned for individual runs;
+The default C<cost> is '08'. This can be also be tuned for individual runs;
 see L</crypt>.
 
 (This is merely a convenience function for calling C<<
 Crypt::Bcrypt::Easy->new >>.)
 
+If your application generates passwords in multiple child processes or
+threads, you can cause L<App::bmkpasswd/mkpasswd_forked> to be automatically
+called during object construction in each individual process by specifying the
+C<reset_seed> option:
+
+  my $bcrypt = bcrypt( reset_seed => 1, cost => 8 );
+
+(The C<reset_seed> option was added in C<v2.7.1>.)
+
 =head3 crypt
 
 Create and return a new password hash:
